@@ -1,9 +1,9 @@
 package App::column::run;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-06'; # DATE
+our $DATE = '2021-03-02'; # DATE
 our $DIST = 'App-column-run'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,17 +24,22 @@ $SPEC{column_run} = {
 This utility is similar to using the Unix utility <prog:pr> to columnate output,
 something like (in bash):
 
-    % pr -t -m -w $COLUMNS -l 99999 <(command1 args...) <(command2 args...)
+    % pr -T -m -w $COLUMNS <(command1 args...) <(command2 args...)
 
-except with the following features:
+except with the following differences:
 
-* ANSI color and wide character handling
+* commands are run in sequence, not in parallel;
 
-* passing adjusted COLUMNS environment to commands so they can adjust output
+* all output are collected first, then displayed;
 
-* Passing common arguments to all commands
+* multiplexing STDIN to all commands;
+
+* ANSI color and wide character handling;
+
+* passing adjusted COLUMNS environment to commands so they can adjust output;
+
+* passing common arguments to all commands.
 
-* Multiplexing STDIN to all commands
 
 _
     args => {
@@ -124,7 +129,7 @@ App::column::run - Run several commands and show their output in multiple column
 
 =head1 VERSION
 
-This document describes version 0.002 of App::column::run (from Perl distribution App-column-run), released on 2020-06-06.
+This document describes version 0.003 of App::column::run (from Perl distribution App-column-run), released on 2021-03-02.
 
 =head1 FUNCTIONS
 
@@ -140,19 +145,23 @@ Run several commands and show their output in multiple columns.
 This utility is similar to using the Unix utility L<pr> to columnate output,
 something like (in bash):
 
- % pr -t -m -w $COLUMNS -l 99999 <(command1 args...) <(command2 args...)
+ % pr -T -m -w $COLUMNS <(command1 args...) <(command2 args...)
 
-except with the following features:
+except with the following differences:
 
 =over
 
-=item * ANSI color and wide character handling
+=item * commands are run in sequence, not in parallel;
 
-=item * passing adjusted COLUMNS environment to commands so they can adjust output
+=item * all output are collected first, then displayed;
 
-=item * Passing common arguments to all commands
+=item * multiplexing STDIN to all commands;
 
-=item * Multiplexing STDIN to all commands
+=item * ANSI color and wide character handling;
+
+=item * passing adjusted COLUMNS environment to commands so they can adjust output;
+
+=item * passing common arguments to all commands.
 
 =back
 
@@ -208,28 +217,19 @@ Source repository is at L<https://github.com/perlancar/perl-App-column-run>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-column-run>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-column-run/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-
-L<pr>. Perinci::To::POD=HASH(0x55c267e37168).
-
-L<column>. Perinci::To::POD=HASH(0x55c267e37168).
-
-L<diff>. Perinci::To::POD=HASH(0x55c267e37168).
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
